==> com.idenfy.idenfySdk-1.2.0.2-sources.jar: com/idenfy/idenfySdk/SdkResponseModels/AutenticationResult/ErrorMessage.java <==
package com.idenfy.idenfySdk.SdkResponseModels.AutenticationResult;

import android.os.Parcel;
import android.os.Parcelable;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class ErrorMessage implements Parcelable {

    @SerializedName("en")
    @Expose
    private String en;
    @SerializedName("lt")
    @Expose
    private String lt;
    @SerializedName("ru")
    @Expose
    private String ru;

    @SerializedName("pl")
    @Expose
    private String pl;

    protected ErrorMessage(Parcel in) {
        en = in.readString();
        lt = in.readString();
        ru = in.readString();
        pl = in.readString();
    }

    public ErrorMessage(String en, String lt, String ru, String pl) {
        this.en = en;
        this.lt = lt;
        this.ru = ru;
        this.pl = pl;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(en);
        dest.writeString(lt);
        dest.writeString(ru);
        dest.writeString(pl);
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<ErrorMessage> CREATOR = new Creator<ErrorMessage>() {
        @Override
        public ErrorMessage createFromParcel(Parcel in) {
            return new ErrorMessage(in);
        }

        @Override
        public ErrorMessage[] newArray(int size) {
            return new ErrorMessage[size];
        }
    };

    public String getEn() {
        return en;
    }

    public void setEn(String en) {
        this.en = en;
    }

    public String getLt() {
        return lt;
    }

    public void setLt(String lt) {
        this.lt = lt;
    }

    public String getRu() {
        return ru;
    }

    public void setRu(String ru) {
        this.ru = ru;
    }

    public String getPl() {
        return pl;
    }

    public void setPl(String pl) {
        this.pl = pl;
    }

    @Override
    public String toString() {
        return "ErrorMessage{" +
                "en='" + en + '\'' +
                ", lt='" + lt + '\'' +
                ", ru='" + ru + '\'' +
                ", pl='" + pl + '\'' +
                '}';
    }
}

==> com.idenfy.idenfySdk-1.3.0-sources.jar: com/idenfy/idenfySdk/SdkResponseModels/AutenticationResult/ErrorMessage.java <==
package com.idenfy.idenfySdk.SdkResponseModels.AutenticationResult;

import android.os.Parcel;
import android.os.Parcelable;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class ErrorMessage implements Parcelable {

    @SerializedName("en")
    @Expose
    private String en;
    @SerializedName("lt")
    @Expose
    private String lt;
    @SerializedName("ru")
    @Expose
    private String ru;

    @SerializedName("pl")
    @Expose
    private String pl;

    @SerializedName("ro")
    @Expose
    private String ro;

    @SerializedName("lv")
    @Expose
    private String lv;

    @SerializedName("fr")
    @Expose
    private String fr;

    @SerializedName("de")
    @Expose
    private String de;

    @SerializedName("it")
    @Expose
    private String it;

    public ErrorMessage(String en, String lt, String ru, String pl, String ro, String lv, String fr, String de, String it) {
        this.en = en;
        this.lt = lt;
        this.ru = ru;
        this.pl = pl;
        this.ro = ro;
        this.lv = lv;
        this.fr = fr;
        this.de = de;
        this.it = it;
    }


    protected ErrorMessage(Parcel in) {
        en = in.readString();
        lt = in.readString();
        ru = in.readString();
        pl = in.readString();
        ro = in.readString();
        lv = in.readString();
        fr = in.readString();
        de = in.readString();
        it = in.readString();
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(en);
        dest.writeString(lt);
        dest.writeString(ru);
        dest.writeString(pl);
        dest.writeString(ro);
        dest.writeString(lv);
        dest.writeString(fr);
        dest.writeString(de);
        dest.writeString(it);
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<ErrorMessage> CREATOR = new Creator<ErrorMessage>() {
        @Override
        public ErrorMessage createFromParcel(Parcel in) {
            return new ErrorMessage(in);
        }

        @Override
        public ErrorMessage[] newArray(int size) {
            return new ErrorMessage[size];
        }
    };

    public String getEn() {
        return en;
    }

    public String getLt() {
        return lt;
    }

    public String getRu() {
        return ru;
    }

    public String getPl() {
        return pl;
    }

    public String getRo() {
        return ro;
    }

    public String getLv() {
        return lv;
    }

    public String getFr() {
        return fr;
    }
    public String getDe() {
        return de;
    }

    public String getIt() {
        return it;
    }

}
